@@ -157,7 +157,10 @@ class Counter(datasets.GeneratorBasedBuilder):
                 source = parse_file(f)
                 example["source"] = source
 
-            derived_file = base_path / (file.stem + "p" + file.suffix)
+            if file.stem == "0032":
+                derived_file = base_path / (file.stem + "P" + file.suffix)
+            else:
+                derived_file = base_path / (file.stem + "p" + file.suffix)
             with derived_file.open(encoding="utf-8") as f:
                 derived = parse_file(f)
                 example["derived"] = derived
