@@ -16,6 +16,7 @@
 
 
 import datasets
+from datasets.tasks import TextClassification
 
 
 _CITATION = """\
@@ -56,6 +57,7 @@ class Ilist(datasets.GeneratorBasedBuilder):
             supervised_keys=None,
             homepage="https://github.com/kmi-linguistics/vardial2018",
             citation=_CITATION,
+            task_templates=[TextClassification(text_column="text", label_column="language_id")],
         )
 
     def _split_generators(self, dl_manager):
