@@ -20,6 +20,7 @@
 import os
 
 import datasets
+from datasets.tasks import TextClassification
 
 
 _DESCRIPTION = """\
@@ -78,6 +79,7 @@ class Imdb(datasets.GeneratorBasedBuilder):
             supervised_keys=None,
             homepage="http://ai.stanford.edu/~amaas/data/sentiment/",
             citation=_CITATION,
+            task_templates=[TextClassification(text_column="text", label_column="label")],
         )
 
     def _vocab_text_gen(self, archive):
