@@ -18,6 +18,7 @@
 import csv
 
 import datasets
+from datasets.tasks import TextClassification
 
 
 _DESCRIPTION = """\
@@ -51,6 +52,7 @@ class KorSarcasm(datasets.GeneratorBasedBuilder):
             supervised_keys=None,
             homepage=_HOMEPAGE,
             license=_LICENSE,
+            task_templates=[TextClassification(text_column="tokens", label_column="label")],
         )
 
     def _split_generators(self, dl_manager):
