@@ -20,6 +20,7 @@
 import csv
 
 import datasets
+from datasets.tasks import TextClassification
 
 
 _DESCRIPTION = """\
@@ -89,6 +90,7 @@ class Labr(datasets.GeneratorBasedBuilder):
             supervised_keys=None,
             homepage="https://github.com/mohamedadaly/LABR",
             citation=_CITATION,
+            task_templates=[TextClassification(text_column="text", label_column="label")],
         )
 
     def _split_generators(self, dl_manager):
