@@ -20,6 +20,7 @@
 import json
 
 import datasets
+from datasets.tasks import QuestionAnsweringExtractive
 
 
 logger = datasets.logging.get_logger(__name__)
@@ -93,6 +94,11 @@ class Piaf(datasets.GeneratorBasedBuilder):
             supervised_keys=None,
             homepage="https://piaf.etalab.studio",
             citation=_CITATION,
+            task_templates=[
+                QuestionAnsweringExtractive(
+                    question_column="question", context_column="context", answers_column="answers"
+                )
+            ],
         )
 
     def _split_generators(self, dl_manager):
