@@ -86,11 +86,11 @@ class QaZre(datasets.GeneratorBasedBuilder):
     def _generate_examples(self, filepaths):
         """Yields examples."""
 
-        for filepath in filepaths:
+        for file_idx, filepath in enumerate(filepaths):
             with open(filepath, encoding="utf-8") as f:
                 data = csv.reader(f, delimiter="\t")
                 for idx, row in enumerate(data):
-                    yield idx, {
+                    yield f"{file_idx}_{idx}", {
                         "relation": row[0],
                         "question": row[1],
                         "subject": row[2],
