@@ -20,6 +20,7 @@
 import os
 
 import datasets
+from datasets.tasks import TextClassification
 
 
 _DESCRIPTION = """\
@@ -58,6 +59,7 @@ class RottenTomatoesMovieReview(datasets.GeneratorBasedBuilder):
             supervised_keys=[""],
             homepage="http://www.cs.cornell.edu/people/pabo/movie-review-data/",
             citation=_CITATION,
+            task_templates=[TextClassification(text_column="text", label_column="label")],
         )
 
     def _vocab_text_gen(self, train_file):
