@@ -4,6 +4,7 @@
 import os
 
 import datasets
+from datasets.tasks import TextClassification
 
 
 logger = datasets.logging.get_logger(__name__)
@@ -36,6 +37,7 @@ class TurkishProductReviews(datasets.GeneratorBasedBuilder):
             ),
             citation=_CITATION,
             homepage=_HOMEPAGE,
+            task_templates=[TextClassification(text_column="sentence", label_column="sentiment")],
         )
 
     def _split_generators(self, dl_manager):
@@ -51,15 +53,15 @@ class TurkishProductReviews(datasets.GeneratorBasedBuilder):
     def _generate_examples(self, filepath, filenames):
         """Generate TurkishProductReviews examples."""
         logger.info("⏳ Generating examples from = %s", filepath)
-        for f in sorted(filenames):
+        for file_idx, f in enumerate(sorted(filenames)):
             filename, file_extension = os.path.splitext(f)
-            label = "negative" if file_extension == "neg" else "positive"
+            label = "negative" if file_extension == ".neg" else "positive"
 
             file_fullpath = os.path.join(filepath, f)
             with open(file_fullpath, encoding="utf-8") as f:
                 for idx, line in enumerate(f):
                     line = line.strip()
-                    yield idx, {
+                    yield f"{file_idx}_{idx}", {
                         "sentence": line,
                         "sentiment": label,
                     }
