@@ -5,6 +5,7 @@ import json
 import os
 
 import datasets
+from datasets.tasks import TextClassification
 
 
 _CITATION = """\
@@ -87,6 +88,7 @@ class WisesightSentiment(datasets.GeneratorBasedBuilder):
             supervised_keys=None,
             homepage="https://github.com/PyThaiNLP/wisesight-sentiment",
             citation=_CITATION,
+            task_templates=[TextClassification(text_column="texts", label_column="category")],
         )
 
     def _split_generators(self, dl_manager):
