@@ -18,13 +18,14 @@
 # pylint: enable=line-too-long
 # pylint: disable=g-import-not-at-top,g-bad-import-order,wrong-import-position
 
-__version__ = "1.10.0"
+__version__ = "1.15.1"
 
 import pyarrow
+from packaging import version as _version
 from pyarrow import total_allocated_bytes
 
 
-if tuple(int(i) for i in pyarrow.__version__.split(".")) < (1, 0, 0):
+if _version.parse(pyarrow.__version__).major < 1:
     raise ImportWarning(
         "To use `datasets`, the module `pyarrow>=1.0.0` is required, and the current version of `pyarrow` doesn't match this condition.\n"
         "If you are running this in a Google Colab, you should probably just restart the runtime to use the right version of `pyarrow`."
@@ -41,6 +42,7 @@ from .features import (
     Array3D,
     Array4D,
     Array5D,
+    Audio,
     ClassLabel,
     Features,
     Sequence,
@@ -53,6 +55,7 @@ from .info import DatasetInfo, MetricInfo
 from .inspect import (
     get_dataset_config_names,
     get_dataset_infos,
+    get_dataset_split_names,
     inspect_dataset,
     inspect_metric,
     list_datasets,
@@ -76,4 +79,4 @@ from .splits import (
 from .utils import *
 
 
-SCRIPTS_VERSION = "master" if __version__.split(".")[-1].startswith("dev") else __version__
+SCRIPTS_VERSION = "master" if _version.parse(__version__).is_devrelease else __version__
