@@ -20,10 +20,17 @@ import socket
 from dataclasses import asdict
 from typing import Any, Dict, List, Optional, Tuple, Union
 
+import numpy as np
 import pyarrow as pa
 
 from . import config, utils
-from .features import Features, _ArrayXDExtensionType
+from .features import (
+    Features,
+    _ArrayXDExtensionType,
+    cast_to_python_objects,
+    list_of_np_array_to_pyarrow_listarray,
+    numpy_to_pyarrow_listarray,
+)
 from .info import DatasetInfo
 from .keyhash import DuplicatedKeysError, KeyHasher
 from .utils import logging
@@ -86,20 +93,42 @@ class TypedSequence:
         """This function is called when calling pa.array(typed_sequence)"""
         assert type is None, "TypedSequence is supposed to be used with pa.array(typed_sequence, type=None)"
         trying_type = False
-        if type is None and self.try_type:
+        if type is not None:  # user explicitly passed the feature
+            pass
+        elif type is None and self.try_type:
             type = self.try_type
             trying_type = True
         else:
             type = self.type
         try:
             if isinstance(type, _ArrayXDExtensionType):
-                out = pa.ExtensionArray.from_storage(type, pa.array(self.data, type.storage_dtype))
+                if isinstance(self.data, np.ndarray):
+                    storage = numpy_to_pyarrow_listarray(self.data, type=type.value_type)
+                elif isinstance(self.data, list) and self.data and isinstance(self.data[0], np.ndarray):
+                    storage = list_of_np_array_to_pyarrow_listarray(self.data, type=type.value_type)
+                else:
+                    storage = pa.array(self.data, type.storage_dtype)
+                out = pa.ExtensionArray.from_storage(type, storage)
+            elif isinstance(self.data, np.ndarray):
+                out = numpy_to_pyarrow_listarray(self.data)
+                if type is not None:
+                    out = out.cast(type)
+            elif isinstance(self.data, list) and self.data and isinstance(self.data[0], np.ndarray):
+                out = list_of_np_array_to_pyarrow_listarray(self.data)
+                if type is not None:
+                    out = out.cast(type)
             else:
-                out = pa.array(self.data, type=type)
-            if trying_type and out[0].as_py() != self.data[0]:
-                raise TypeError(
-                    "Specified try_type alters data. Please check that the type/feature that you provided match the type/features of the data."
+                out = pa.array(cast_to_python_objects(self.data, only_1d_for_numpy=True), type=type)
+            if trying_type:
+                is_equal = (
+                    np.array_equal(np.array(out[0].as_py()), self.data[0])
+                    if isinstance(self.data[0], np.ndarray)
+                    else out[0].as_py() == self.data[0]
                 )
+                if not is_equal:
+                    raise TypeError(
+                        "Specified try_type alters data. Please check that the type/feature that you provided match the type/features of the data."
+                    )
             if self.optimized_int_type and self.type is None and self.try_type is None:
                 if pa.types.is_int64(out.type):
                     out = out.cast(self.optimized_int_type)
@@ -111,15 +140,20 @@ class TypedSequence:
             return out
         except (TypeError, pa.lib.ArrowInvalid) as e:  # handle type errors and overflows
             if trying_type:
-                try:
-                    return pa.array(self.data, type=None)  # second chance
+                try:  # second chance
+                    if isinstance(self.data, np.ndarray):
+                        return numpy_to_pyarrow_listarray(self.data)
+                    elif isinstance(self.data, list) and self.data and isinstance(self.data[0], np.ndarray):
+                        return list_of_np_array_to_pyarrow_listarray(self.data)
+                    else:
+                        return pa.array(cast_to_python_objects(self.data, only_1d_for_numpy=True))
                 except pa.lib.ArrowInvalid as e:
                     if "overflow" in str(e):
                         raise OverflowError(
                             "There was an overflow with type {}. Try to reduce writer_batch_size to have batches smaller than 2GB.\n({})".format(
                                 type_(self.data), e
                             )
-                        )
+                        ) from None
                     else:
                         raise
             elif "overflow" in str(e):
@@ -127,7 +161,7 @@ class TypedSequence:
                     "There was an overflow with type {}. Try to reduce writer_batch_size to have batches smaller than 2GB.\n({})".format(
                         type_(self.data), e
                     )
-                )
+                ) from None
             else:
                 raise
 
@@ -292,11 +326,13 @@ class ArrowWriter:
             inferred_type = pa_array.type
             first_example = pa.array(OptimizedTypedSequence(typed_sequence.data[:1], type=inferred_type))[0]
             if pa_array[0] != first_example:  # Sanity check (check for overflow in StructArray or ListArray)
-                raise OverflowError(
-                    "There was an overflow in the {}. Try to reduce writer_batch_size to have batches smaller than 2GB".format(
-                        type(pa_array)
+                # This check fails with FloatArrays with nans, which is not what we want, so account for that:
+                if not isinstance(pa_array[0], pa.lib.FloatScalar):
+                    raise OverflowError(
+                        "There was an overflow in the {}. Try to reduce writer_batch_size to have batches smaller than 2GB".format(
+                            type(pa_array)
+                        )
                     )
-                )
             arrays.append(pa_array)
             inferred_types.append(inferred_type)
         schema = pa.schema(zip(cols, inferred_types)) if self.pa_writer is None else self._schema
@@ -372,10 +408,14 @@ class ArrowWriter:
         writer_batch_size: Optional[int] = None,
     ):
         """Write a batch of Example to file.
+        Ignores the batch if it appears to be empty,
+        preventing a potential schema update of unknown types.
 
         Args:
-            example: the Example to add.
+            batch_examples: the batch of examples to add.
         """
+        if batch_examples and len(next(iter(batch_examples.values()))) == 0:
+            return
         schema = None if self.pa_writer is None and self.update_features else self._schema
         try_schema = self._schema if self.pa_writer is None and self.update_features else None
         typed_sequence_examples = {}
@@ -511,7 +551,7 @@ class BeamWriter:
                 parquet_to_arrow(sources, dest)
         except socket.error as e:  # broken pipe can happen if the connection is unstable, do local conversion instead
             if e.errno != errno.EPIPE:  # not a broken pipe
-                raise e
+                raise
             logger.warning("Broken Pipe during stream conversion from parquet to arrow. Using local convert instead")
             local_convert_dir = os.path.join(self._cache_dir, "beam_convert")
             os.makedirs(local_convert_dir, exist_ok=True)
@@ -545,10 +585,4 @@ def parquet_to_arrow(sources, destination):
                     df[col] = df[col].apply(json.loads)
                 reconstructed_table = pa.Table.from_pandas(df)
                 writer.write_table(reconstructed_table)
-    # Collect the gc or the tqdm progress bar keeps references to the open files
-    # and it causes permission errors on windows
-    # see https://app.circleci.com/pipelines/github/huggingface/datasets/6365/workflows/24f7c960-3176-43a5-9652-7830a23a981e/jobs/39232
-    import gc
-
-    gc.collect()
     return destination
