@@ -1,7 +1,7 @@
 import copy
 from dataclasses import dataclass
 from itertools import cycle, islice, repeat
-from typing import Any, Callable, Dict, Iterable, Iterator, List, Optional
+from typing import Any, Callable, Dict, Iterable, Iterator, List, Optional, Union
 
 import numpy as np
 import pyarrow as pa
@@ -194,7 +194,10 @@ class MappedExamplesIterable(_BaseExamplesIterable):
     def shuffle_data_sources(self, seed: Optional[int]) -> "MappedExamplesIterable":
         """Shuffle the wrapped examples iterable."""
         return MappedExamplesIterable(
-            self.ex_iterable.shuffle_data_sources(seed), function=self.function, batch_size=self.batch_size
+            self.ex_iterable.shuffle_data_sources(seed),
+            function=self.function,
+            batched=self.batched,
+            batch_size=self.batch_size,
         )
 
     @property
@@ -290,7 +293,7 @@ def _generate_examples_from_tables_wrapper(generate_tables_fn):
 
 
 @dataclass
-class ShuffingConfig:
+class ShufflingConfig:
     seed: Optional[int] = None
 
 
@@ -303,7 +306,7 @@ class IterableDataset(DatasetInfoMixin):
         info: Optional[DatasetInfo] = None,
         split: Optional[NamedSplit] = None,
         format_type: Optional[str] = None,
-        shuffling: Optional[ShuffingConfig] = None,
+        shuffling: Optional[ShufflingConfig] = None,
     ):
         info = info.copy() if info is not None else DatasetInfo()
         DatasetInfoMixin.__init__(self, info=info, split=split)
@@ -422,7 +425,7 @@ class IterableDataset(DatasetInfoMixin):
             buffer_size (:obj:`int`): size of the buffer.
             seed (:obj:`int`, optional, default None): random seed that will be used to create the distribution.
         """
-        shuffling = ShuffingConfig(seed=seed)
+        shuffling = ShufflingConfig(seed=seed)
         return iterable_dataset(
             ex_iterable=BufferShuffledExamplesIterable(self._ex_iterable, buffer_size, seed=seed).shuffle_data_sources(
                 seed=seed
@@ -468,13 +471,33 @@ class IterableDataset(DatasetInfoMixin):
             shuffling=copy.deepcopy(self._shuffling),
         )
 
+    def remove_columns(self, column_names: Union[str, List[str]]) -> "IterableDataset":
+        """
+        Remove one or several column(s) in the dataset and the features associated to them.
+        The removal is done on-the-fly on the examples when iterating over the dataset.
+
+
+        Args:
+            column_names (:obj:`Union[str, List[str]]`): Name of the column(s) to remove.
+
+        Returns:
+            :class:`IterableDataset`: A copy of the dataset object without the columns to remove.
+        """
+        if isinstance(column_names, str):
+            column_names = [column_names]
+
+        def remove_fn(example):
+            return {k: v for k, v in example.items() if k not in column_names}
+
+        return self.map(remove_fn)
+
 
 def iterable_dataset(
     ex_iterable: Iterable,
     info: Optional[DatasetInfo] = None,
     split: Optional[NamedSplit] = None,
     format_type: Optional[str] = None,
-    shuffling: Optional[ShuffingConfig] = None,
+    shuffling: Optional[ShufflingConfig] = None,
 ):
     if format_type is not None and format_type == "torch":
         import torch
